# Niska — Investigation Review

Part of the ShadowStrike War Room Suite.

Niska is a collaborative investigation review platform — the connective thread between forensic processing and legal production.

> Active development in progress. Full release coming soon.

## ShadowStrike Suite

| Package | Role |
|---|---|
| **Niki** | Forensic parser |
| **Komanda** | Case management |
| **Niska** | Investigation review |
| **Sila** | Evidence management |
| **Vistina** | Legal review |

## Author

GitHub: [ShadowStrike-CTF](https://github.com/ShadowStrike-CTF)
